spacepy.pycdf.CDFException — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »

# spacepy.pycdf.CDFException

class `spacepy.pycdf.` `CDFException`(status)

  Base class for errors or warnings in the CDF library.

  Not normally used directly, but in subclasses `CDFError` and `CDFWarning`.

  Error messages provided by this class are looked up from the underlying C library.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »